@@ -311,7 +311,7 @@ impl Vote {
             from,
             transaction,
             wallclock,
-            slot: vote.slots.last().copied(),
+            slot: vote.last_voted_slot(),
         })
     }
 
