@@ -2,7 +2,7 @@
 #![allow(clippy::integer_arithmetic)]
 
 pub mod cluster_info;
-mod cluster_info_metrics;
+pub mod cluster_info_metrics;
 #[macro_use]
 pub mod contact_info;
 pub mod crds;
